# Changelog

## 1.6.0 (2025-06-24)

Full Changelog: [v1.5.0...v1.6.0](https://github.com/oregister/openregister-python/compare/v1.5.0...v1.6.0)

### Features

* **api:** update via SDK Studio ([ba142a6](https://github.com/oregister/openregister-python/commit/ba142a6ecc663b673b65deeb6d89e9a8c169155e))
* **api:** update via SDK Studio ([0bd9e3c](https://github.com/oregister/openregister-python/commit/0bd9e3c3deb69a9713ace31371d998f03e503fca))
* **client:** add support for aiohttp ([7edb08a](https://github.com/oregister/openregister-python/commit/7edb08a37f1d0d5df0cd3de806a5406efe857d98))


### Chores

* **tests:** skip some failing tests on the latest python versions ([8d990dd](https://github.com/oregister/openregister-python/commit/8d990dd5dd4f3e8a9a3e01989f7b59a68021f709))

## 1.5.0 (2025-06-20)

Full Changelog: [v1.4.0...v1.5.0](https://github.com/oregister/openregister-python/compare/v1.4.0...v1.5.0)

### Features

* **api:** update via SDK Studio ([4eac8c2](https://github.com/oregister/openregister-python/commit/4eac8c2d786342ab445c9b062a9dc97a997e6d40))

## 1.4.0 (2025-06-20)

Full Changelog: [v1.3.0...v1.4.0](https://github.com/oregister/openregister-python/compare/v1.3.0...v1.4.0)

### Features

* **api:** update via SDK Studio ([c1f7f0b](https://github.com/oregister/openregister-python/commit/c1f7f0bb504bec37a98c229182987eb74cdf7732))
* **api:** update via SDK Studio ([29e115d](https://github.com/oregister/openregister-python/commit/29e115d98dd34e7f2320406e3d71fe9a4c5f34d1))


### Bug Fixes

* **client:** correctly parse binary response | stream ([3178a60](https://github.com/oregister/openregister-python/commit/3178a608d0bea505c36ee0dd53beef0b9637d3e2))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([9ff0d2d](https://github.com/oregister/openregister-python/commit/9ff0d2d45e64f8decc4d4f27f552b92fade72818))


### Chores

* **ci:** enable for pull requests ([2267910](https://github.com/oregister/openregister-python/commit/22679109aeef09c71cbf8297b1540792e9e1238e))
* **internal:** update conftest.py ([3159827](https://github.com/oregister/openregister-python/commit/3159827569407d2abd0a48610ba421cbe8bb1a1f))
* **readme:** update badges ([067d506](https://github.com/oregister/openregister-python/commit/067d5068b7c90cf0285f45e8942c9fd35d12db1a))
* **tests:** add tests for httpx client instantiation & proxies ([933aead](https://github.com/oregister/openregister-python/commit/933aead45e63051438e6d2b7ca22302df1735d3f))
* **tests:** run tests in parallel ([4f120e1](https://github.com/oregister/openregister-python/commit/4f120e11a6c102b6a9e976cb10e780d2d617115a))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([e20479c](https://github.com/oregister/openregister-python/commit/e20479cd0e2e9fd3121713e7f168c503949230aa))

## 1.3.0 (2025-06-09)

Full Changelog: [v1.2.0...v1.3.0](https://github.com/oregister/openregister-python/compare/v1.2.0...v1.3.0)

### Features

* **api:** update via SDK Studio ([50198fb](https://github.com/oregister/openregister-python/commit/50198fb41cbf7c4b93df4fe4c3967126ae0e8b09))
* **api:** update via SDK Studio ([42905b5](https://github.com/oregister/openregister-python/commit/42905b56702cbf59d1ba582f112598fcab4ac435))
* **api:** update via SDK Studio ([ad4e5f4](https://github.com/oregister/openregister-python/commit/ad4e5f4ae5715443f4eddf2e09b2c4137ba89eb9))

## 1.2.0 (2025-06-09)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/oregister/openregister-python/compare/v1.1.0...v1.2.0)

### Features

* **api:** update via SDK Studio ([228c918](https://github.com/oregister/openregister-python/commit/228c918a0281457e4a07ebc56925fa5fb40469e8))

## 1.1.0 (2025-06-07)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/oregister/openregister-python/compare/v1.0.1...v1.1.0)

### Features

* **api:** update via SDK Studio ([87a3573](https://github.com/oregister/openregister-python/commit/87a3573991bc19fadd1c4c92c1d90fab80687c7f))

## 1.0.1 (2025-06-07)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/oregister/openregister-python/compare/v1.0.0...v1.0.1)

### Chores

* **internal:** version bump ([722cc66](https://github.com/oregister/openregister-python/commit/722cc66631a7d16ed42771fcff10b2382c1ee6f1))

## 1.0.0 (2025-06-07)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/oregister/openregister-python/compare/v0.0.1-alpha.0...v1.0.0)

### Features

* **api:** update via SDK Studio ([a018c07](https://github.com/oregister/openregister-python/commit/a018c0797b5296e8029e051d36dda94c909b0128))


### Chores

* configure new SDK language ([82da76d](https://github.com/oregister/openregister-python/commit/82da76d60986b6e1a49752ff77d7616f7e022aab))
* update SDK settings ([b3e38ee](https://github.com/oregister/openregister-python/commit/b3e38ee33379b4d063bef466fcbc69672d266815))
* update SDK settings ([145faf6](https://github.com/oregister/openregister-python/commit/145faf6f39192c044fd30bed4395085af8a487ac))
* update SDK settings ([8c2aa41](https://github.com/oregister/openregister-python/commit/8c2aa412e3660f742e3febc22364937dfb373cc4))
